package
module
Version:
v0.0.3
Opens a new window with list of versions in this module.
Published: Jun 10, 2021
License: GPL-3.0
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 3
Opens a new window with list of known importers.
README
¶
snmphelper
Helpers on top of gosnmp
Documentation
¶
Package snmphelper implements some functions on top of gosnmp.
type Session struct {
Host, User, Prot, Pass, Slevel, PrivProt, PrivPass string
Ver int
MaxRepetitions, Timeout uint32
Snmp *gosnmp.GoSNMP
}
SNMP session object
Initializes and returns *gosnmp.GoSNMP in Session.Snmp
type SnmpOut map[string]snmpValue
Session.Result data type. SNMP query results will appear here.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.